@@ -5,8 +5,12 @@
 import subprocess
 import sys
 import unittest
+
+# Prevent loading PyXML
+import xml
+xml.__path__ = [x for x in xml.__path__ if "_xmlplus" not in x]
+
 import xml.dom.minidom
-import StringIO
 
 import imp
 dont_write_bytecode = sys.dont_write_bytecode
@@ -18,6 +22,8 @@ for x in dir(ndiff):
 sys.dont_write_bytecode = dont_write_bytecode
 del dont_write_bytecode
 
+import StringIO
+
 
 class scan_test(unittest.TestCase):
     """Test the Scan class."""
