@@ -14,8 +14,6 @@
 #include "nse_fs.h"
 #include "nse_nsock.h"
 #include "nse_nmaplib.h"
-#include "nse_bit.h"
-#include "nse_binlib.h"
 #include "nse_pcrelib.h"
 #include "nse_openssl.h"
 #include "nse_debug.h"
@@ -41,6 +39,7 @@
 
 #define NSE_FORMAT_TABLE "NSE_FORMAT_TABLE"
 #define NSE_FORMAT_XML "NSE_FORMAT_XML"
+#define NSE_PARALLELISM "NSE_PARALLELISM"
 
 #ifndef MAXPATHLEN
 #  define MAXPATHLEN 2048
@@ -122,7 +121,7 @@ static int script_set_output (lua_State *L)
   sr.set_output_tab(L, 2);
   if (!lua_isnil(L, 3)) {
     lua_len(L, 3);
-    sr.set_output_str(luaL_checkstring(L, 3), luaL_checkint(L,-1));
+    sr.set_output_str(luaL_checkstring(L, 3), luaL_checkinteger(L,-1));
   }
   script_scan_results.push_back(sr);
   return 0;
@@ -136,7 +135,7 @@ static int host_set_output (lua_State *L)
   sr.set_output_tab(L, 3);
   if (!lua_isnil(L, 4)) {
     lua_len(L, 4);
-    sr.set_output_str(luaL_checkstring(L, 4), luaL_checkint(L,-1));
+    sr.set_output_str(luaL_checkstring(L, 4), luaL_checkinteger(L,-1));
   }
   target->scriptResults.push_back(sr);
   return 0;
@@ -153,7 +152,7 @@ static int port_set_output (lua_State *L)
   sr.set_output_tab(L, 4);
   if (!lua_isnil(L, 5)) {
     lua_len(L, 5);
-    sr.set_output_str(luaL_checkstring(L, 5), luaL_checkint(L,-1));
+    sr.set_output_str(luaL_checkstring(L, 5), luaL_checkinteger(L,-1));
   }
   target->ports.addScriptResult(p->portno, p->proto, sr);
   target->ports.numscriptresults++;
@@ -385,6 +384,7 @@ static void open_cnse (lua_State *L)
   nseU_setsfield(L, -1, "scriptargs", o.scriptargs);
   nseU_setsfield(L, -1, "scriptargsfile", o.scriptargsfile);
   nseU_setsfield(L, -1, "NMAP_URL", NMAP_URL);
+  nseU_setnfield(L, -1, "script_timeout", o.scripttimeout);
 
 }
 
@@ -442,7 +442,7 @@ static std::string format_obj(lua_State *L, int pos)
   }
 
   lua_len(L, -1);
-  output = std::string(lua_tostring(L, -2), luaL_checkint(L, -1));
+  output = std::string(lua_tostring(L, -2), luaL_checkinteger(L, -1));
   lua_pop(L, 1);
 
   return output;
@@ -543,8 +543,6 @@ static void set_nmap_libraries (lua_State *L)
   static const luaL_Reg libs[] = {
     {NSE_PCRELIBNAME, luaopen_pcrelib},
     {NSE_NMAPLIBNAME, luaopen_nmap},
-    {NSE_BINLIBNAME, luaopen_binlib},
-    {BITLIBNAME, luaopen_bit},
     {LFSLIBNAME, luaopen_lfs},
     {LPEGLIBNAME, luaopen_lpeg},
 #ifdef HAVE_OPENSSL
@@ -593,6 +591,10 @@ static int init_main (lua_State *L)
   lua_call(L, 2, 1); /* returns the NSE main function */
 
   lua_setfield(L, LUA_REGISTRYINDEX, NSE_MAIN);
+
+  lua_pushinteger(L, o.min_parallelism);
+  lua_setfield(L, LUA_REGISTRYINDEX, NSE_PARALLELISM);
+
   return 0;
 }
 
@@ -660,7 +662,7 @@ static int run_main (lua_State *L)
  * correct and only way to call is as a tail call:
  *   return nse_yield(L, 0, NULL);
  */
-int nse_yield (lua_State *L, int ctx, lua_CFunction k)
+int nse_yield (lua_State *L, lua_KContext ctx, lua_KFunction k)
 {
   lua_getfield(L, LUA_REGISTRYINDEX, NSE_YIELD);
   lua_pushthread(L);
@@ -780,8 +782,8 @@ void open_nse (void)
     double minor = fmod(*version, 10.0);
     if (o.debugging >= 1)
       log_write(LOG_STDOUT, "%s: Using Lua %.0f.%.0f.\n", SCRIPT_ENGINE, major, minor);
-    if (*version < 502)
-      fatal("%s: This version of NSE only works with Lua 5.2 or greater.", SCRIPT_ENGINE);
+    if (*version < 503)
+      fatal("%s: This version of NSE only works with Lua 5.3 or greater.", SCRIPT_ENGINE);
     if ((L_NSE = luaL_newstate()) == NULL)
       fatal("%s: failed to open a Lua state!", SCRIPT_ENGINE);
     lua_atpanic(L_NSE, panic);
