@@ -4,7 +4,7 @@
  *                                                                         *
  ***********************IMPORTANT NSOCK LICENSE TERMS***********************
  *                                                                         *
- * The nsock parallel socket event library is (C) 1999-2013 Insecure.Com   *
+ * The nsock parallel socket event library is (C) 1999-2016 Insecure.Com   *
  * LLC This library is free software; you may redistribute and/or          *
  * modify it under the terms of the GNU General Public License as          *
  * published by the Free Software Foundation; Version 2.  This guarantees  *
@@ -28,8 +28,7 @@
  *                                                                         *
  * Source is provided to this software because we believe users have a     *
  * right to know exactly what a program is going to do before they run it. *
- * This also allows you to audit the software for security holes (none     *
- * have been found so far).                                                *
+ * This also allows you to audit the software for security holes.          *
  *                                                                         *
  * Source code also allows you to port Nmap to new platforms, fix bugs,    *
  * and add new features.  You are highly encouraged to send your changes   *
@@ -54,7 +53,7 @@
  *                                                                         *
  ***************************************************************************/
 
-/* $Id: nsock_write.c 31562 2013-07-28 22:05:05Z fyodor $ */
+/* $Id: nsock_write.c 35831 2016-06-01 16:51:50Z dmiller $ */
 
 #include "nsock.h"
 #include "nsock_internal.h"
@@ -67,16 +66,16 @@
 
 nsock_event_id nsock_sendto(nsock_pool ms_pool, nsock_iod ms_iod, nsock_ev_handler handler, int timeout_msecs,
                             void *userdata, struct sockaddr *saddr, size_t sslen, unsigned short port, const char *data, int datalen) {
-  mspool *nsp = (mspool *)ms_pool;
-  msiod *nsi = (msiod *)ms_iod;
-  msevent *nse;
+  struct npool *nsp = (struct npool *)ms_pool;
+  struct niod *nsi = (struct niod *)ms_iod;
+  struct nevent *nse;
   char displaystr[256];
   struct sockaddr_in *sin = (struct sockaddr_in *)saddr;
 #if HAVE_IPV6
   struct sockaddr_in6 *sin6 = (struct sockaddr_in6 *)saddr;
 #endif
 
-  nse = msevent_new(nsp, NSE_TYPE_WRITE, nsi, timeout_msecs, handler, userdata);
+  nse = event_new(nsp, NSE_TYPE_WRITE, nsi, timeout_msecs, handler, userdata);
   assert(nse);
 
   if (saddr->sa_family == AF_INET) {
@@ -105,7 +104,7 @@ nsock_event_id nsock_sendto(nsock_pool ms_pool, nsock_iod ms_iod, nsock_ev_handl
   if (datalen < 0)
     datalen = (int) strlen(data);
 
-  if (nsp->loglevel == NSOCK_LOG_DBG_ALL && datalen < 80) {
+  if (NsockLogLevel == NSOCK_LOG_DBG_ALL && datalen < 80) {
     memcpy(displaystr, ": ", 2);
     memcpy(displaystr + 2, data, datalen);
     displaystr[2 + datalen] = '\0';
@@ -113,12 +112,13 @@ nsock_event_id nsock_sendto(nsock_pool ms_pool, nsock_iod ms_iod, nsock_ev_handl
   } else {
     displaystr[0] = '\0';
   }
-  nsock_log_debug(nsp, "Sendto request for %d bytes to IOD #%li EID %li [%s]%s",
-                  datalen, nsi->id, nse->id, get_peeraddr_string(nse->iod), displaystr);
+  nsock_log_info("Sendto request for %d bytes to IOD #%li EID %li [%s]%s",
+                 datalen, nsi->id, nse->id, get_peeraddr_string(nse->iod),
+                 displaystr);
 
   fs_cat(&nse->iobuf, data, datalen);
 
-  nsp_add_event(nsp, nse);
+  nsock_pool_add_event(nsp, nse);
 
   return nse->id;
 }
@@ -129,12 +129,12 @@ nsock_event_id nsock_sendto(nsock_pool ms_pool, nsock_iod ms_iod, nsock_ev_handl
  * will figure out the length itself */
 nsock_event_id nsock_write(nsock_pool ms_pool, nsock_iod ms_iod,
           nsock_ev_handler handler, int timeout_msecs, void *userdata, const char *data, int datalen) {
-  mspool *nsp = (mspool *)ms_pool;
-  msiod *nsi = (msiod *)ms_iod;
-  msevent *nse;
+  struct npool *nsp = (struct npool *)ms_pool;
+  struct niod *nsi = (struct niod *)ms_iod;
+  struct nevent *nse;
   char displaystr[256];
 
-  nse = msevent_new(nsp, NSE_TYPE_WRITE, nsi, timeout_msecs, handler, userdata);
+  nse = event_new(nsp, NSE_TYPE_WRITE, nsi, timeout_msecs, handler, userdata);
   assert(nse);
 
   nse->writeinfo.dest.ss_family = AF_UNSPEC;
@@ -142,21 +142,22 @@ nsock_event_id nsock_write(nsock_pool ms_pool, nsock_iod ms_iod,
   if (datalen < 0)
     datalen = (int)strlen(data);
 
-    if (nsp->loglevel == NSOCK_LOG_DBG_ALL && datalen < 80) {
-      memcpy(displaystr, ": ", 2);
-      memcpy(displaystr + 2, data, datalen);
-      displaystr[2 + datalen] = '\0';
-      replacenonprintable(displaystr + 2, datalen, '.');
-    } else {
-      displaystr[0] = '\0';
-    }
+  if (NsockLogLevel == NSOCK_LOG_DBG_ALL && datalen < 80) {
+    memcpy(displaystr, ": ", 2);
+    memcpy(displaystr + 2, data, datalen);
+    displaystr[2 + datalen] = '\0';
+    replacenonprintable(displaystr + 2, datalen, '.');
+  } else {
+    displaystr[0] = '\0';
+  }
 
-    nsock_log_debug(nsp, "Write request for %d bytes to IOD #%li EID %li [%s]%s",
-                    datalen, nsi->id, nse->id, get_peeraddr_string(nsi), displaystr);
+  nsock_log_info("Write request for %d bytes to IOD #%li EID %li [%s]%s",
+      datalen, nsi->id, nse->id, get_peeraddr_string(nsi),
+      displaystr);
 
   fs_cat(&nse->iobuf, data, datalen);
 
-  nsp_add_event(nsp, nse);
+  nsock_pool_add_event(nsp, nse);
 
   return nse->id;
 }
@@ -164,9 +165,9 @@ nsock_event_id nsock_write(nsock_pool ms_pool, nsock_iod ms_iod,
 /* Same as nsock_write except you can use a printf-style format and you can only use this for ASCII strings */
 nsock_event_id nsock_printf(nsock_pool ms_pool, nsock_iod ms_iod,
           nsock_ev_handler handler, int timeout_msecs, void *userdata, char *format, ...) {
-  mspool *nsp = (mspool *)ms_pool;
-  msiod *nsi = (msiod *)ms_iod;
-  msevent *nse;
+  struct npool *nsp = (struct npool *)ms_pool;
+  struct niod *nsi = (struct niod *)ms_iod;
+  struct nevent *nse;
   char buf[4096];
   char *buf2 = NULL;
   int res, res2;
@@ -176,7 +177,7 @@ nsock_event_id nsock_printf(nsock_pool ms_pool, nsock_iod ms_iod,
   va_list ap;
   va_start(ap,format);
 
-  nse = msevent_new(nsp, NSE_TYPE_WRITE, nsi, timeout_msecs, handler, userdata);
+  nse = event_new(nsp, NSE_TYPE_WRITE, nsi, timeout_msecs, handler, userdata);
   assert(nse);
 
   res = Vsnprintf(buf, sizeof(buf), format, ap);
@@ -210,7 +211,9 @@ nsock_event_id nsock_printf(nsock_pool ms_pool, nsock_iod ms_iod,
     }
   }
 
-  if (nsp->loglevel == NSOCK_LOG_DBG_ALL && nse->status != NSE_STATUS_ERROR && strlength < 80) {
+  if (NsockLogLevel == NSOCK_LOG_DBG_ALL &&
+      nse->status != NSE_STATUS_ERROR &&
+      strlength < 80) {
     memcpy(displaystr, ": ", 2);
     memcpy(displaystr + 2, buf2, strlength);
     displaystr[2 + strlength] = '\0';
@@ -219,13 +222,14 @@ nsock_event_id nsock_printf(nsock_pool ms_pool, nsock_iod ms_iod,
     displaystr[0] = '\0';
   }
 
-  nsock_log_debug(nsp, "Write request for %d bytes to IOD #%li EID %li [%s]%s",
-                  strlength, nsi->id, nse->id, get_peeraddr_string(nsi), displaystr);
+  nsock_log_info("Write request for %d bytes to IOD #%li EID %li [%s]%s",
+                 strlength, nsi->id, nse->id, get_peeraddr_string(nsi),
+                 displaystr);
 
   if (buf2 != buf)
     free(buf2);
 
-  nsp_add_event(nsp, nse);
+  nsock_pool_add_event(nsp, nse);
 
   return nse->id;
 }
