@@ -3,7 +3,7 @@
 
 # ***********************IMPORTANT NMAP LICENSE TERMS************************
 # *                                                                         *
-# * The Nmap Security Scanner is (C) 1996-2014 Insecure.Com LLC. Nmap is    *
+# * The Nmap Security Scanner is (C) 1996-2016 Insecure.Com LLC. Nmap is    *
 # * also a registered trademark of Insecure.Com LLC.  This program is free  *
 # * software; you may redistribute and/or modify it under the terms of the  *
 # * GNU General Public License as published by the Free Software            *
@@ -94,8 +94,7 @@
 # *                                                                         *
 # * Source is provided to this software because we believe users have a     *
 # * right to know exactly what a program is going to do before they run it. *
-# * This also allows you to audit the software for security holes (none     *
-# * have been found so far).                                                *
+# * This also allows you to audit the software for security holes.          *
 # *                                                                         *
 # * Source code also allows you to port Nmap to new platforms, fix bugs,    *
 # * and add new features.  You are highly encouraged to send your changes   *
@@ -116,7 +115,7 @@
 # * WITHOUT ANY WARRANTY; without even the implied warranty of              *
 # * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the Nmap      *
 # * license file for more details (it's in a COPYING file included with     *
-# * Nmap, and also available from https://svn.nmap.org/nmap/COPYING         *
+# * Nmap, and also available from https://svn.nmap.org/nmap/COPYING)        *
 # *                                                                         *
 # ***************************************************************************/
 
@@ -167,11 +166,11 @@ class NdiffCommand(subprocess.Popen):
         search_paths = get_path()
         env = dict(os.environ)
         env["PATH"] = search_paths
-        if getattr(sys, "frozen", None) == "macosx_app":
-            # These variables are set by py2app, but they can interfere with
+        if "Zenmap.app" in sys.executable:
+            # These vars are set by the launcher, but they can interfere with
             # Ndiff because Ndiff is also a Python application. Without
             # removing these, Ndiff will attempt to run using the
-            # py2app-bundled Python library, and may run into version or
+            # bundled Python library, and may run into version or
             # architecture mismatches.
             if "PYTHONPATH" in env:
                 del env["PYTHONPATH"]
