@@ -3,7 +3,7 @@
 
 # ***********************IMPORTANT NMAP LICENSE TERMS************************
 # *                                                                         *
-# * The Nmap Security Scanner is (C) 1996-2014 Insecure.Com LLC. Nmap is    *
+# * The Nmap Security Scanner is (C) 1996-2016 Insecure.Com LLC. Nmap is    *
 # * also a registered trademark of Insecure.Com LLC.  This program is free  *
 # * software; you may redistribute and/or modify it under the terms of the  *
 # * GNU General Public License as published by the Free Software            *
@@ -94,8 +94,7 @@
 # *                                                                         *
 # * Source is provided to this software because we believe users have a     *
 # * right to know exactly what a program is going to do before they run it. *
-# * This also allows you to audit the software for security holes (none     *
-# * have been found so far).                                                *
+# * This also allows you to audit the software for security holes.          *
 # *                                                                         *
 # * Source code also allows you to port Nmap to new platforms, fix bugs,    *
 # * and add new features.  You are highly encouraged to send your changes   *
@@ -116,7 +115,7 @@
 # * WITHOUT ANY WARRANTY; without even the implied warranty of              *
 # * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the Nmap      *
 # * license file for more details (it's in a COPYING file included with     *
-# * Nmap, and also available from https://svn.nmap.org/nmap/COPYING         *
+# * Nmap, and also available from https://svn.nmap.org/nmap/COPYING)        *
 # *                                                                         *
 # ***************************************************************************/
 
@@ -135,7 +134,7 @@ import xml.sax
 
 from zenmapGUI.higwidgets.higdialogs import HIGAlertDialog, HIGDialog
 from zenmapGUI.higwidgets.higboxes import HIGVBox, HIGHBox, \
-        hig_box_space_holder
+    hig_box_space_holder
 from zenmapGUI.higwidgets.higlabels import HIGSectionLabel
 from zenmapGUI.higwidgets.higtables import HIGTable
 from zenmapGUI.higwidgets.higbuttons import HIGButton
@@ -202,7 +201,7 @@ class ScanChooser(HIGVBox):
 
     def show_scan(self, widget):
         nmap_output = self.get_nmap_output()
-        if nmap_output is not None:
+        if nmap_output:
             self.txt_scan_result.get_buffer().set_text(nmap_output)
 
     def normalize_output(self, output):
@@ -215,7 +214,7 @@ class ScanChooser(HIGVBox):
     def _attaching_widgets(self):
         self.table.attach(self.combo_scan, 0, 1, 0, 1, yoptions=0)
         self.table.attach(
-                self.btn_open_scan, 1, 2, 0, 1, yoptions=0, xoptions=0)
+            self.btn_open_scan, 1, 2, 0, 1, yoptions=0, xoptions=0)
         self.table.attach(self.exp_scan, 0, 2, 1, 2)
 
     def _set_scrolled(self):
@@ -239,7 +238,7 @@ class ScanChooser(HIGVBox):
         self.txt_scan_result.set_wrap_mode(gtk.WRAP_WORD)
         self.txt_scan_result.set_editable(False)
         self.txt_scan_result.get_buffer().connect(
-                "changed", self._text_changed_cb)
+            "changed", self._text_changed_cb)
 
     def _set_open_button(self):
         self.btn_open_scan.connect('clicked', self.open_file)
@@ -254,7 +253,7 @@ class ScanChooser(HIGVBox):
             try:
                 parser = NmapParser()
                 parser.parse_file(file_chosen)
-            except xml.sax.SAXParseException, e:
+            except xml.sax.SAXParseException as e:
                 alert = HIGAlertDialog(
                     message_format='<b>%s</b>' % _('Error parsing file'),
                     secondary_text=_(
@@ -263,13 +262,13 @@ class ScanChooser(HIGVBox):
                 alert.run()
                 alert.destroy()
                 return False
-            except Exception, e:
+            except Exception as e:
                 alert = HIGAlertDialog(
-                        message_format='<b>%s</b>' % _(
-                            'Cannot open selected file'),
-                        secondary_text=_("""\
-                            This error occurred while trying to open the file:
-                            %s""") % str(e))
+                    message_format='<b>%s</b>' % _(
+                        'Cannot open selected file'),
+                    secondary_text=_("""\
+                        This error occurred while trying to open the file:
+                        %s""") % str(e))
                 alert.run()
                 alert.destroy()
                 return False
@@ -292,7 +291,7 @@ class ScanChooser(HIGVBox):
     def _text_changed_cb(self, widget):
         buff = self.txt_scan_result.get_buffer()
         buff.apply_tag(
-                self.txg_tag, buff.get_start_iter(), buff.get_end_iter())
+            self.txg_tag, buff.get_start_iter(), buff.get_end_iter())
 
     def get_parsed_scan(self):
         """Return the currently selected scan's parsed output as an NmapParser
@@ -303,7 +302,10 @@ class ScanChooser(HIGVBox):
     def get_nmap_output(self):
         """Return the currently selected scan's output as a string, or None if
         no valid scan is selected."""
-        return self.parsed_scan.get_nmap_output()
+        if self.parsed_scan is not None:
+            return self.parsed_scan.get_nmap_output()
+        else:
+            return None
 
     nmap_output = property(get_nmap_output)
     parsed_scan = property(get_parsed_scan)
@@ -386,7 +388,7 @@ class DiffWindow(gtk.Window):
         else:
             try:
                 self.ndiff_process = zenmapCore.Diff.ndiff(scan_a, scan_b)
-            except OSError, e:
+            except OSError as e:
                 alert = HIGAlertDialog(
                     message_format=_("Error running ndiff"),
                     secondary_text=_(
@@ -398,7 +400,7 @@ class DiffWindow(gtk.Window):
                 self.progress.show()
                 if self.timer_id is None:
                     self.timer_id = gobject.timeout_add(
-                            NDIFF_CHECK_TIMEOUT, self.check_ndiff_process)
+                        NDIFF_CHECK_TIMEOUT, self.check_ndiff_process)
 
     def check_ndiff_process(self):
         """Check if the ndiff subprocess is done and show the diff if it is.
@@ -423,7 +425,7 @@ class DiffWindow(gtk.Window):
                 # Successful completion.
                 try:
                     diff = self.ndiff_process.get_scan_diff()
-                except zenmapCore.Diff.NdiffParseException, e:
+                except zenmapCore.Diff.NdiffParseException as e:
                     alert = HIGAlertDialog(
                         message_format=_("Error parsing ndiff output"),
                         secondary_text=str(e))
@@ -434,8 +436,8 @@ class DiffWindow(gtk.Window):
             else:
                 # Unsuccessful completion.
                 error_text = _(
-                        "The ndiff process terminated with status code %d."
-                        ) % status
+                    "The ndiff process terminated with status code %d."
+                    ) % status
                 stderr = self.ndiff_process.stderr.read()
                 if len(stderr) > 0:
                     error_text += "\n\n" + stderr
@@ -474,7 +476,7 @@ class DiffView(gtk.TextView):
         # Create text markup tags.
         buff.create_tag("=", font="Monospace")
         buff.create_tag(
-                "-", font="Monospace", background=self.REMOVE_COLOR)
+            "-", font="Monospace", background=self.REMOVE_COLOR)
         buff.create_tag("+", font="Monospace", background=self.ADD_COLOR)
 
     def clear(self):
